'\" Copyright (c) 2002 by Kevin B. Kenny.  All rights reserved.
'\"
'\" RCS: #(@) $Id: combinatorics.n,v 1.2 2002/01/18 20:51:16 andreas_kupries Exp $
'\"
.so man.macros
.TH combinatorics n 1.2 math "Tcl Math Library"
.BS
'\" Note: do not modify the .SH NAME line immediately below
.SH NAME
combinatorics - Combinatorial functions in the Tcl Math Library
.SH SYNOPSIS
\fBpackage require Tcl 8.2\fR
.sp
\fBpackage require math 1.2\fR
.sp
\fB::math::ln_Gamma\fR \fIz\fR
.sp
\fB::math::factorial\fR \fIn\fR
.sp
\fB::math::choose\fR \fIn k\fR
.sp
\fB::math::Beta\fR \fIz w\fR
.sp
.BE
.SH DESCRIPTION
.PP
The \fBmath\fR package contains implementations of several functions
useful in combinatorial problems.
.SH COMMANDS
.TP
\fB::math::ln_Gamma\fR \fIz\fR
Returns the natural logarithm of the Gamma function for the argument \fIz\fR.
.PP
The Gamma function is defined as the improper integral from 
zero to positive infinity of
.CS
\fIt**(x-1)*exp(-t) dt\fR.
.CE
.PP
The approximation used in the Tcl Math Library is from Lanczos, \fISIAM
J. Numerical Analysis, series B,\fR volume 1, p. 86.  For \fIx>1\fR, the
absolute error of the result is claimed to be smaller than 5.5*10**-10
-- that is, the resulting value of Gamma when 
.CS
exp( ln_Gamma( x) ) 
.CE
is computed is expected to be precise to better than nine
significant figures.
.TP
\fB::math::factorial\fR \fIx\fR
Returns the factorial of the argument \fIx\fR.
.PP
For integer \fIx\fR, \fI0 <= x <= 12\fR, an exact integer result is returned.
.PP
For integer \fIx\fR, \fI13 <= x <= 21\fR, an exact floating-point
result is returned on machines with IEEE floating point.
.PP
For integer \fIx\fR, \fI22 <= x <= 170\fR, the result is exact to 1 ULP.
.PP
For real \fIx\fR, \fIx >= 0\fR, the result is approximated by computing
\fIGamma(x+1)\fR using the \fB::math::ln_Gamma\fR function, and the result is
expected to be precise to better than nine significant figures.
.PP
It is an error to present \fIx <= -1\fR or \fIx > 170\fR, or a value
of \fIx\fR that is not numeric.
.TP
\fB::math::choose\fR \fIn k\fR
Returns the binomial coefficient \fIC(n, k)\fR
.CS
\fIC(n,k) = n! / k! (n-k)!
.CE
If both parameters are integers and the result fits in 32 bits, 
the result is rounded to an integer.
.PP
Integer results are exact up to at least \fIn = 34\fR.
Floating point results are precise to better than nine significant 
figures.
.TP
\fB::math::Beta\fR \fIz w\fR
Returns the Beta function of the parameters \fIz\fR and \fIw\fR.
.CS
\fIBeta(z,w) = Beta(w,z) = Gamma(z) * Gamma(w) / Gamma(z+w)
.CE
Results are returned as a floating point number precise to better than
nine significant digits provided that \fIw\fR and \fIz\fR are both at
least 1.

